
shelephant
==========

.. toctree::
   :caption: BASICS
   :maxdepth: 1

   getting.rst
   copying.rst
   dataset.rst

.. toctree::
   :caption: API
   :maxdepth: 1

   dataset_api.rst
   cli.rst
   python.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
